@@ -33,12 +33,19 @@
 #' @param hl A string specifying the ISO language code (ex.: \dQuote{en-US} or
 #'   \dQuote{fr}). Default is \dQuote{en-US}. Note that this is only influencing
 #'   the data returned by related topics.
+#'   
+#' @param tz A number specifying the minutes the returned dates should be offset to UTC. 
+#' Note the parameter 'time' above is specified in UTC. 
+#' E.g. choosing "time=2018-01-01T01 2018-01-01T03" and "tz=-120" will yield data between 2018-01-01T03 and 2018-01-01T05, 
+#' i.e. data specified to be in UTC+2.
 #'
 #' @param low_search_volume Logical. Should include low search volume regions?
 #'
 #' @param cookie_url A string specifying the URL from which to obtain cookies.
 #'   Default should work in general; should only be changed by advanced users.
 #'
+#' @param onlyInterest If you only want the interest over time set it to TRUE.
+#' 
 #' @section Categories: The package includes a complete list of categories that
 #'   can be used to narrow requests. These can be accessed using
 #'   \code{data("categories")}.
@@ -109,14 +116,17 @@ gtrends <- function(
                     category = 0,
                     hl = "en-US",
                     low_search_volume = FALSE,
-                    cookie_url = "http://trends.google.com/Cookies/NID") {
+                    cookie_url = "http://trends.google.com/Cookies/NID",
+                    tz=0, # This equals UTC
+                    onlyInterest=FALSE
+                    ) {
   stopifnot(
     # One  vector should be a multiple of the other
-    (length(keyword) %% length(geo) == 0) || (length(geo) %% length(keyword) == 0),
+    (length(keyword) %% length(geo) == 0) || (length(geo) %% length(keyword) == 0) || (length(time) %% length(keyword) == 0),
     is.vector(keyword),
     length(keyword) <= 5,
     length(geo) <= 5,
-    length(time) == 1,
+    length(time) <= 5,
     length(hl) == 1,
     is.character(hl),
     hl %in% language_codes$code,
@@ -144,7 +154,15 @@ gtrends <- function(
 
   ## Check if time format is ok
   if (!check_time(time)) {
-    stop("Can not parse the supplied time format.", call. = FALSE)
+    stop("Cannot parse the supplied time format.", call. = FALSE)
+  }
+  
+  if(!(is.numeric(tz))){
+    if (tz %in% OlsonNames()){
+      tz <- map_tz2min(tz)
+    }else{
+      stop("Given timezone not known. Check function OlsonNames().", call. = FALSE)
+    }
   }
 
   # time <- "today+5-y"
@@ -163,29 +181,32 @@ gtrends <- function(
   # ****************************************************************************
   # Request a token from Google
   # ****************************************************************************
+  comparison_item <- data.frame(geo, time,keyword, stringsAsFactors = FALSE)
 
-  comparison_item <- data.frame(keyword, geo, time, stringsAsFactors = FALSE)
-
-  widget <- get_widget(comparison_item, category, gprop, hl, cookie_url)
+  widget <- get_widget(comparison_item, category, gprop, hl, cookie_url,tz)
 
   # ****************************************************************************
   # Now that we have tokens, we can process the queries
   # ****************************************************************************
 
-  interest_over_time <- interest_over_time(widget, comparison_item)
-  interest_by_region <- interest_by_region(widget, comparison_item, low_search_volume)
-  related_topics <- related_topics(widget, comparison_item, hl)
-  related_queries <- related_queries(widget, comparison_item)
-
-  res <- list(
-    interest_over_time = interest_over_time,
-    interest_by_country = do.call(rbind, interest_by_region[names(interest_by_region) == "country"]),
-    interest_by_region = do.call(rbind, interest_by_region[names(interest_by_region) == "region"]),
-    interest_by_dma = do.call(rbind, interest_by_region[names(interest_by_region) == "dma"]),
-    interest_by_city = do.call(rbind, interest_by_region[names(interest_by_region) == "city"]),
-    related_topics = related_topics,
-    related_queries = related_queries
-  )
+  interest_over_time <- interest_over_time(widget, comparison_item,tz)
+  
+  if(!onlyInterest){
+    interest_by_region <- interest_by_region(widget, comparison_item, low_search_volume,tz)
+    related_topics <- related_topics(widget, comparison_item, hl,tz)
+    related_queries <- related_queries(widget, comparison_item,tz)
+    res <- list(
+      interest_over_time = interest_over_time,
+      interest_by_country = do.call(rbind, interest_by_region[names(interest_by_region) == "country"]),
+      interest_by_region = do.call(rbind, interest_by_region[names(interest_by_region) == "region"]),
+      interest_by_dma = do.call(rbind, interest_by_region[names(interest_by_region) == "dma"]),
+      interest_by_city = do.call(rbind, interest_by_region[names(interest_by_region) == "city"]),
+      related_topics = related_topics,
+      related_queries = related_queries
+    )
+  }else{
+    res <- list(interest_over_time = interest_over_time)
+  }
 
   ## Remove row.names
   res <- lapply(res, function(x) {
